pub struct FunctionLifterContext {
pub function: Ref<LowLevelILMutableFunction>,
pub platform: Ref<Platform>,
pub logger: Ref<Logger>,
pub blocks: Vec<Ref<BasicBlock<NativeBlock>>>,
pub no_return_calls: HashSet<Location>,
pub contextual_returns: HashMap<Location, bool>,
pub inlined_remapping: HashMap<Location, Location>,
pub user_indirect_branches: HashMap<Location, HashSet<Location>>,
pub auto_indirect_branches: HashMap<Location, HashSet<Location>>,
pub inlined_calls: HashSet<u64>,
/* private fields */
}Fields
function: Ref<LowLevelILMutableFunction>platform: Ref<Platform>logger: Ref<Logger>blocks: Vec<Ref<BasicBlock<NativeBlock>>>no_return_calls: HashSet<Location>contextual_returns: HashMap<Location, bool>inlined_remapping: HashMap<Location, Location>user_indirect_branches: HashMap<Location, HashSet<Location>>auto_indirect_branches: HashMap<Location, HashSet<Location>>inlined_calls: HashSet<u64>Implementations
Sourceimpl FunctionLifterContext
impl FunctionLifterContext
pub unsafe fn from_raw( function: *mut BNLowLevelILFunction, handle: *mut BNFunctionLifterContext, ) -> Self
pub fn prepare_block_translation( &self, func: &LowLevelILMutableFunction, arch: &CoreArchitecture, address: u64, )
Sourcepub fn lifter_instruction_data(&self) -> Option<LifterInstructionData>
pub fn lifter_instruction_data(&self) -> Option<LifterInstructionData>
The per-function instruction byte store populated during basic block analysis. Read it here to avoid reading the view during lifting.
pub fn get_function_arch_context<A: ArchitectureWithFunctionContext>( &self, _arch: &A, ) -> Option<&A::FunctionArchContext>